summaryrefslogtreecommitdiffstats
path: root/arts/gui/kde/kpopupbox_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'arts/gui/kde/kpopupbox_impl.h')
-rw-r--r--arts/gui/kde/kpopupbox_impl.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/arts/gui/kde/kpopupbox_impl.h b/arts/gui/kde/kpopupbox_impl.h
index ebda82c5..0cd44a4e 100644
--- a/arts/gui/kde/kpopupbox_impl.h
+++ b/arts/gui/kde/kpopupbox_impl.h
@@ -26,21 +26,21 @@
#include <artsgui.h>
class TQBoxLayout;
-class KPopupBox_widget;
-//class KPopupBoxEventMapper; // The EventMapper isn't needed at present, but perhaps in the future...
+class TDEPopupBox_widget;
+//class TDEPopupBoxEventMapper; // The EventMapper isn't needed at present, but perhaps in the future...
namespace Arts {
/// The PopupBox
-class KPopupBox_impl : virtual public Arts::PopupBox_skel, public Arts::KFrame_impl
+class TDEPopupBox_impl : virtual public Arts::PopupBox_skel, public Arts::KFrame_impl
{
public:
/// selfreference like 'this'
PopupBox self() { return PopupBox::_from_base( _copy() ); }
/// Constructor
- KPopupBox_impl( KPopupBox_widget *w=0 );
- ~KPopupBox_impl();
+ TDEPopupBox_impl( TDEPopupBox_widget *w=0 );
+ ~TDEPopupBox_impl();
/// The name of the widget
std::string name();
@@ -57,10 +57,10 @@ public:
private:
std::string _name;
bool _lefttoright;
- KPopupBox_widget *_widget;
-// KPopupBoxEventMapper *_mapper;
+ TDEPopupBox_widget *_widget;
+// TDEPopupBoxEventMapper *_mapper;
-}; // class KPopupBox
+}; // class TDEPopupBox
} // namespace Arts